

RegistryResults
====================================

.. currentmodule:: pyvo.registry.regtap

.. autoclass:: RegistryResults
   :show-inheritance:

   
     
   

   
   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~RegistryResults.getrecord

   
   

   
   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: getrecord

   
   